@@ -50,10 +50,11 @@ gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 			       gchar **error)
 {
 	gchar *msg, **parts;
+	GyrusImapStatus status;
+
 	msg = g_strdup_printf (". getquota \"%s\"\n", mailbox_path);
 	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
-	GyrusImapStatus status;
 
 	*error = NULL;
 	
@@ -85,7 +86,7 @@ gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 	return TRUE;
 }
 
-void
+static void
 gyrus_admin_mailbox_get_human_quota (gint quota, gchar *str_quota)
 {
 	gchar* prefix;
@@ -192,12 +193,14 @@ gyrus_admin_mailbox_show_info (GyrusAdmin *admin, const gchar *user,
 void
 gyrus_admin_mailbox_clear_info (GyrusAdmin *admin)
 {
+	GtkListStore *store;
+
 	gtk_label_set_text (GTK_LABEL (admin->priv->label_mailbox_name), "");
 	gtk_label_set_text (GTK_LABEL (admin->priv->label_mailbox_owner), "");
 	gtk_label_set_text (GTK_LABEL (admin->priv->label_quota_limit), "");
 	gtk_label_set_text (GTK_LABEL (admin->priv->label_quota_free), "");
 
-	GtkListStore *store = GTK_LIST_STORE
+	store = GTK_LIST_STORE
 		(gtk_tree_view_get_model (admin->priv->treeview_acl));
 	gtk_list_store_clear (store);
 }
@@ -211,6 +214,7 @@ gyrus_admin_mailbox_on_button_quota_apply_clicked (GtkButton *button,
 	const gchar *new_quota_str;
 	gint new_quota;
 	gchar *new_quota_invalid;
+	gchar *mailbox_path;
 
 	new_quota_str =
 		gtk_entry_get_text (GTK_ENTRY (admin->priv->entry_quota_new));
@@ -218,9 +222,8 @@ gyrus_admin_mailbox_on_button_quota_apply_clicked (GtkButton *button,
 	if (!g_ascii_strcasecmp (new_quota_str, ""))
 		return;
 	
-	gchar *mailbox_path =
-		g_strdup (gtk_label_get_text
-			  (GTK_LABEL (admin->priv->label_mailbox_name)));
+	mailbox_path = g_strdup (gtk_label_get_text
+				 (GTK_LABEL (admin->priv->label_mailbox_name)));
 
 	new_quota = 1024 * g_strtod (new_quota_str, &new_quota_invalid);
 
@@ -255,7 +258,7 @@ gyrus_admin_mailbox_on_entry_quota_new_activate (GtkEntry *entry,
 	gtk_button_clicked (button);
 }
 
-gboolean
+static gboolean
 gyrus_admin_mailbox_exists (GyrusAdmin *admin,
 			    const gchar *mailbox)
 {
@@ -282,7 +285,7 @@ gyrus_admin_mailbox_exists (GyrusAdmin *admin,
 	return FALSE;
 }
 
-gboolean 
+static gboolean 
 gyrus_admin_mailbox_name_is_valid (GyrusAdmin *admin, const gchar *mailbox)
 {
 	return (/*!g_strrstr (mailbox, " ") &&*/
@@ -322,7 +325,9 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 {
 	GIOError ioerror = G_IO_ERROR_NONE;
 	GyrusImapStatus status;
-	
+	gchar *new_mailbox;
+	gchar *msg;
+
 	if (!gyrus_admin_mailbox_name_is_valid (admin, mailbox)) {
 		*error = g_strdup_printf (_("'%s' is not a valid "
 					    "mailbox name. Please try a different one."),
@@ -338,7 +343,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 		return FALSE;
 	}
 	
-	gchar *new_mailbox = g_strconcat (path, gyrus_admin_get_separator_char (admin), 
+	new_mailbox = g_strconcat (path, gyrus_admin_get_separator_char (admin), 
 					  mailbox, NULL);
 
 	if (gyrus_admin_mailbox_exists (admin, new_mailbox)) {
@@ -348,7 +353,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 		return FALSE;
 	}
 
-	gchar *msg = g_strdup_printf (". create \"%s\"\n", new_mailbox);
+	msg = g_strdup_printf (". create \"%s\"\n", new_mailbox);
 	ioerror = gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
@@ -376,14 +381,17 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 /* Returns a GList of all the mailboxes under a given mailbox.
    This list must be freed, and also it's elements.
  */
-GList *
+static GList *
 gyrus_admin_get_submailboxes (GyrusAdmin *admin,
 			      const gchar *mailbox)
 {
 	GList *list = NULL;
 	gchar *c_mailbox;
-		
-	gchar *msg = g_strdup_printf (". list \"%s\" *\n", mailbox);
+	gchar *msg;
+
+	g_assert (GYRUS_IS_ADMIN (admin));
+
+	msg = g_strdup_printf (". list \"%s\" *\n", mailbox);
 	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
@@ -405,14 +413,19 @@ gyrus_admin_get_submailboxes (GyrusAdmin *admin,
 	return list;
 }
 
-gboolean
+static gboolean
 gyrus_admin_mailbox_delete (GyrusAdmin *admin,
 			    const gchar *mailbox,
 			    gchar **error)
 {
-	gchar *msg = g_strdup_printf (". delete \"%s\"\n",
-				      mailbox);
 	GyrusImapStatus status;
+	gchar *msg;
+	
+	g_assert (GYRUS_IS_ADMIN (admin));
+
+	msg = g_strdup_printf (". delete \"%s\"\n",
+			       mailbox);
+
 	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
@@ -435,6 +448,8 @@ gyrus_admin_mailbox_delete_all (GyrusAdmin *admin,
 	GList *list;
 	GList *iter = NULL;
 	gchar *error;
+
+	g_assert (GYRUS_IS_ADMIN (admin));
 	
 	list = gyrus_admin_get_submailboxes (admin, mailbox);
 
@@ -481,7 +496,8 @@ void
 gyrus_admin_acl_set_tree_view (GyrusAdmin *admin, const gchar *mailbox_path)
 {
 	GtkTreeIter iter;
-	GList *list = NULL;
+	GList *list = NULL;	
+	GList *l_iter;
 	GtkTreeModel *model;
 	gchar *error;
 	
@@ -507,8 +523,6 @@ gyrus_admin_acl_set_tree_view (GyrusAdmin *admin, const gchar *mailbox_path)
 	gtk_widget_hide (admin->priv->label_acl);
 	gtk_widget_show (GTK_WIDGET (admin->priv->scrolled_acl));
 	
-	GList *l_iter;
-	
 	for (l_iter = list; l_iter != NULL; l_iter = g_list_next (l_iter)) {
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
@@ -617,6 +631,8 @@ gyrus_admin_add_acl_entry (GyrusAdmin *admin)
 	GtkTreePath *path;
 	gboolean duplicated = FALSE;
 	GyrusImapAclEntry *entry;
+	GList *l_iter;
+	gint i;
 	const gchar* mailbox = gtk_label_get_text (GTK_LABEL (admin->priv->label_mailbox_name));
 
 	gchar *default_entry_name = g_strdup (_("new entry"));
@@ -631,14 +647,14 @@ gyrus_admin_add_acl_entry (GyrusAdmin *admin)
 
 	/* check it the new name already exists. */
 
-	gint i = 0;
+	i = 0;
 	do {
 		if (i > 0) {
 			g_free (entry_name);
 			entry_name = g_strdup_printf ("%s %i", default_entry_name, i);
 			duplicated = FALSE;
 		}
-		GList *l_iter = acl;
+		l_iter = acl;
 		while (l_iter != NULL && !duplicated) {
 			entry = GYRUS_IMAP_ACL_ENTRY (l_iter->data);
 			if (strcmp (entry->identifier, entry_name) == 0)
@@ -647,7 +663,7 @@ gyrus_admin_add_acl_entry (GyrusAdmin *admin)
 		}
 		if (duplicated)
 			i++;
-	}while (duplicated);
+	} while (duplicated);
 	
 	gyrus_admin_acl_list_free (acl);
 	
