@@ -26,21 +26,33 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <string.h>
+#include <glib/gi18n.h>
 
-#include "glib/gi18n.h"
 #include "gyrus-main-app.h"
 #include "gyrus-admin.h"
 #include "gyrus-common.h"
 #include "gyrus-session.h"
+#include "gyrus-admin-private.h"
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-admin-acl.h"
-#include "gyrus-marshal.h"
 
+#define GYRUS_ADMIN_GET_PRIVATE(object)                           \
+	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GYRUS_TYPE_ADMIN, GyrusAdminPrivate))
 
-/* #define DEBUG_PLAIN_CHANNEL*/
+G_DEFINE_TYPE (GyrusAdmin, gyrus_admin, GTK_TYPE_VBOX)
+
+/* #define DEBUG_PLAIN_CHANNEL */
+
+enum {
+	CONNECTED,
+	DISCONNECTED,
+	ACL_SELECTION_CHANGED,
+	MAILBOX_SELECTION_CHANGED,
+	SIGNAL_LAST
+};
+
+static gint admin_signals [SIGNAL_LAST];
 
-static void gyrus_admin_class_init (GyrusAdminClass *class);
-static void gyrus_admin_init (GyrusAdmin *admin);
 static void gyrus_admin_finalize (GObject *object);
 static void gyrus_admin_destroy (GtkObject *object);
 
@@ -80,38 +92,10 @@ void gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext
 gboolean
 gyrus_admin_logout (GyrusAdmin *admin);
 
-static GtkVBoxClass *parent_class = NULL;
 #define BUFFER_SIZE 10240
 
 /*** private methods ****/
 
-GType
-gyrus_admin_get_type (void)
-{
-	static GType type = 0;
-  
-	if (!type) {
-		static const GTypeInfo info = {
-				sizeof (GyrusAdminClass),
-				NULL,           /* base_init */
-				NULL,           /* base_finalize */
-				(GClassInitFunc) gyrus_admin_class_init,
-				NULL,           /* class_finalize */
-				NULL,           /* class_data */
-				sizeof (GyrusAdmin),
-				0,              /* n_preallocs */
-				(GInstanceInitFunc) gyrus_admin_init,
-				0
-		};
-		
-		type = g_type_register_static (GTK_TYPE_VBOX,
-					       "GyrusAdmin",
-					       &info, 0);
-	}
-	
-	return type;
-}
-
 static void
 gyrus_admin_class_init (GyrusAdminClass *class)
 {
@@ -122,12 +106,12 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 		G_TYPE_BOOLEAN
 	};
 	
-	parent_class = g_type_class_peek_parent (class);
+	gyrus_admin_parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->finalize = gyrus_admin_finalize;
 	object_class->destroy = gyrus_admin_destroy;
 	
-	class->connected_signal_id = 
+	admin_signals [CONNECTED] = 
 		g_signal_newv ("connected", 
 			       G_TYPE_FROM_CLASS (class),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
@@ -139,7 +123,7 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 			       0     /* n_params */,
 			       NULL  /* param_types */);
 
-	class->disconnected_signal_id = 
+	admin_signals [DISCONNECTED] = 
 		g_signal_newv ("disconnected", 
 			       G_TYPE_FROM_CLASS (class),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
@@ -151,30 +135,31 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 			       0     /* n_params */,
 			       NULL  /* param_types */);
 
-	class->acl_entry_selection_changed = 
-		g_signal_newv ("acl-entry-selection-changed", 
+	admin_signals [ACL_SELECTION_CHANGED] = 
+		g_signal_newv ("acl-selection-changed", 
 			       G_TYPE_FROM_CLASS (class),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 			       NULL /* class closure */,
 			       NULL /* accumulator */,
 			       NULL /* accu_data */,
-			       gyrus_VOID__BOOLEAN,
+			       g_cclosure_marshal_VOID__BOOLEAN,
 			       G_TYPE_NONE /* return_type */,
 			       1     /* n_params */,
 			       selection_changed_types /* param_types */);
 
-	class->mailbox_selection_changed = 
+	admin_signals [MAILBOX_SELECTION_CHANGED] = 
 		g_signal_newv ("mailbox-selection-changed", 
 			       G_TYPE_FROM_CLASS (class),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 			       NULL /* class closure */,
 			       NULL /* accumulator */,
 			       NULL /* accu_data */,
-			       gyrus_VOID__BOOLEAN,
+			       g_cclosure_marshal_VOID__BOOLEAN,
 			       G_TYPE_NONE /* return_type */,
 			       1     /* n_params */,
 			       selection_changed_types /* param_types */);
 
+	g_type_class_add_private (class, sizeof(GyrusAdminPrivate));
 }
 
 static void
@@ -239,7 +224,7 @@ gyrus_admin_init_get_widgets (GyrusAdmin *admin)
 	admin->priv = priv;
 }
 
-void
+static void
 gyrus_admin_init_connect_signals (GyrusAdmin *admin)
 {
 	g_signal_connect (G_OBJECT (admin->priv->button_connect), "clicked",
@@ -264,7 +249,7 @@ gyrus_admin_init_connect_signals (GyrusAdmin *admin)
 static void
 gyrus_admin_init (GyrusAdmin *admin)
 {
-	admin->priv = g_new0 (GyrusAdminPrivate, 1);
+	admin->priv = GYRUS_ADMIN_GET_PRIVATE (admin);
 	admin->priv->session = NULL;
 	
 	gyrus_admin_init_get_widgets (admin);
@@ -286,8 +271,8 @@ gyrus_admin_finalize (GObject *object)
 		gyrus_admin_logout (admin);
 	
 	gyrus_session_free (admin->priv->session);
-	g_free (admin->priv);
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+
+	G_OBJECT_CLASS (gyrus_admin_parent_class)->finalize (object);
 }
 
 static void
@@ -297,7 +282,7 @@ gyrus_admin_destroy (GtkObject *object)
 	g_return_if_fail (GYRUS_IS_ADMIN (object));
 	admin = GYRUS_ADMIN (object);
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	GTK_OBJECT_CLASS (gyrus_admin_parent_class)->destroy (object);
 }
 
 GtkTreeModel *
@@ -336,7 +321,7 @@ gyrus_admin_get_mailbox_from_list_message (gchar *msg)
 	return mb_name;
 }
 
-void
+static void
 gyrus_admin_set_separator_char_auto (GyrusAdmin *admin)
 {
 	gchar **str_v;
@@ -359,7 +344,7 @@ gyrus_admin_set_separator_char_auto (GyrusAdmin *admin)
 	g_strfreev (str_v);
 }
 
-void
+static void
 gyrus_admin_get_users_list (GyrusAdmin *admin)
 {
 	GtkTreeStore *store;
@@ -492,7 +477,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 	g_free (msg);
 }
 
-gboolean
+static gboolean
 gyrus_admin_on_treeview_focused (GtkWidget *widget,
 				 GtkDirectionType arg1,
 				 gpointer data)
@@ -513,14 +498,14 @@ static void
 gyrus_admin_initialize_mailbox_tree_view (GyrusAdmin *admin, 
 					  gboolean is_orphaned)
 {
-	g_return_if_fail (GYRUS_IS_ADMIN (admin));
-	
 	GtkTreeView *treeview;
 	GtkTreeModel *model;
 	GtkTreeViewColumn* column;
 	GtkCellRenderer *renderer;
 	GtkTreeSelection *selection;
 
+	g_return_if_fail (GYRUS_IS_ADMIN (admin));
+	
 	if (is_orphaned) {
 		treeview = admin->priv->treeview_corrupt_mailbox;
 	} else {
@@ -592,15 +577,12 @@ gyrus_admin_acl_tree_model_new (void)
 static void
 gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin)
 {
-	g_return_if_fail (GYRUS_IS_ADMIN (admin));
-
-	GtkTreeView *view = admin->priv->treeview_acl;
-
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *selection;
 	GtkListStore *model;
-	
+	GtkTreeView *view;
+	gint i;
 	gchar *perms[9] = {
 		_("lookup"),
 		_("read"),
@@ -613,8 +595,10 @@ gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin)
 		_("admin")
 	};
 
-	gint i;
+	g_return_if_fail (GYRUS_IS_ADMIN (admin));
 
+	view = admin->priv->treeview_acl;
+	
 	column = gtk_tree_view_column_new ();
 	gtk_tree_view_column_set_title (column, _("Identifier"));
 	gtk_tree_view_column_set_resizable (column, TRUE);
@@ -675,15 +659,15 @@ gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin)
 	gtk_tree_view_set_model (view, GTK_TREE_MODEL (model));
 }
 
-GTcpSocket *
+static GTcpSocket *
 gyrus_admin_create_socket_from_session (GyrusSession *session)
 {
-	g_return_val_if_fail (session, NULL);
-	
 	GInetAddr *addr;
 	GTcpSocket *sock;
 	gchar *msg;
 
+	g_return_val_if_fail (session, NULL);
+	
 	addr = gnet_inetaddr_new (session->host, session->port);
 	if (!addr) {
 		msg = g_strdup_printf (_("%s could not be found. Please check the name and try again."),
@@ -707,7 +691,7 @@ gyrus_admin_create_socket_from_session (GyrusSession *session)
 	return sock;
 }
 
-void
+static void
 gyrus_admin_initialize_channel (GyrusAdmin *admin)
 {
 	g_return_if_fail (admin->priv->iochannel == NULL);
@@ -719,19 +703,18 @@ gyrus_admin_initialize_channel (GyrusAdmin *admin)
 }
 
 /* Allocates @msg_len bytes of memory to store the message.
-   Returns the kind of message readed */ 
+   Returns the kind of message read */ 
 GyrusImapStatus
 gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 {
 	gchar buffer[BUFFER_SIZE];
-	guint bytes_read;
+	gsize bytes_read;
 	gchar **tokens = NULL;
 	GIOError error;
-	
-	*message = NULL;
-
 	GyrusImapStatus imap_status;
 
+	*message = NULL;
+
 	/* Trick to ignore the ALERTs */
 
 	do {
@@ -750,7 +733,7 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 		}
 		
 #ifdef DEBUG_PLAIN_CHANNEL
-		g_print ("readed:  %s", buffer);
+		g_print ("read:  %s", buffer);
 #endif
 		*message = g_strdup (buffer);
 		tokens = g_strsplit (*message, " ", 0);
@@ -785,7 +768,8 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 GIOError
 gyrus_admin_write_channel (GyrusAdmin *admin, gchar *message)
 {
-	guint msg_len, bytes_written;
+	guint msg_len;
+	gsize bytes_written;
 	GIOError error = G_IO_ERROR_NONE;
 
 	msg_len = g_utf8_strlen (message, -1);
@@ -817,14 +801,14 @@ gyrus_admin_logout (GyrusAdmin *admin)
 	return (status == GYRUS_IMAP_STATUS_BYE);
 }
 
-void
+static void
 gyrus_admin_clean_mailbox_treeview (GtkTreeView *treeview, const gchar *title)
 {
-	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
-
 	GtkTreeStore *store;
 	GtkTreeViewColumn *column;
 	
+	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
+
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (treeview)));
 	gtk_tree_store_clear (store);
 
@@ -853,18 +837,60 @@ gyrus_admin_logged_out (GyrusAdmin *admin)
 	gyrus_admin_mailbox_clear_info (admin);
 	gyrus_admin_mailbox_set_sensitive (admin, FALSE);
 	
-	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->acl_entry_selection_changed,
+	g_signal_emit (admin, admin_signals [ACL_SELECTION_CHANGED],
 		       0,
 		       NULL);
+	g_signal_emit (admin, admin_signals [DISCONNECTED],
+		       0, NULL);
 	
 }
 
+/* This function was taken from camel.
+   Copyright 2000 Ximian, Inc. (www.ximian.com)
+*/
+/**
+ * imap_quote_string:
+ * @str: the string to quote, which must not contain CR or LF
+ *
+ * Return value: an IMAP "quoted" corresponding to the string, which
+ * the caller must free.
+ **/
+static char *
+imap_quote_string (const char *str)
+{
+	const char *p;
+	char *quoted, *q;
+	int len;
+	
+	g_assert (strchr (str, '\r') == NULL);
+	
+	len = strlen (str);
+	p = str;
+	while ((p = strpbrk (p, "\"\\"))) {
+		len++;
+		p++;
+	}
+	
+	quoted = q = g_malloc (len + 3);
+	*q++ = '"';
+	for (p = str; *p; ) {
+		if (strchr ("\"\\", *p))
+			*q++ = '\\';
+		*q++ = *p++;
+	}
+	*q++ = '"';
+	*q = '\0';
+	
+	return quoted;
+}
+
 /* returns whether the conection can be established or not. */
-GyrusAdminLoginError
+static GyrusAdminLoginError
 gyrus_admin_login (GyrusAdmin *admin)
 {
 	GTcpSocket *socket;
 	gchar *msg;
+	gchar *q_password;
 	GyrusImapStatus status;
 	GyrusAdminLoginError error = GYRUS_ADMIN_LOGIN_OK;
 	socket = gyrus_admin_create_socket_from_session (admin->priv->session);
@@ -879,10 +905,12 @@ gyrus_admin_login (GyrusAdmin *admin)
 	g_free (msg);
 
 	g_return_val_if_fail (status == GYRUS_IMAP_STATUS_OK, FALSE);
-	
+
+	q_password = imap_quote_string (gyrus_admin_get_current_passwd (admin));
 	msg = g_strdup_printf (". login \"%s\" %s\n",
 			       gyrus_admin_get_current_user (admin),
-			       gyrus_admin_get_current_passwd (admin));
+			       q_password);
+	g_free (q_password);
 	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
@@ -910,27 +938,27 @@ gyrus_admin_login (GyrusAdmin *admin)
 	return error;
 }
 
-void
+static void
 gyrus_admin_post_login (GyrusAdmin *admin)
 {
 	if (strcmp (gyrus_admin_get_separator_char (admin), "auto") == 0)
 		gyrus_admin_set_separator_char_auto (admin);
 
-	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->connected_signal_id,
+	g_signal_emit (admin, admin_signals [CONNECTED],
 		       0,
 		       NULL);
 	
 	gyrus_admin_get_users_list (admin);
 }
 
-void
+static void
 gyrus_admin_pre_logout (GyrusAdmin *admin)
 {
 	gyrus_admin_logout (admin);
 	gyrus_admin_logged_out (admin);
 }
 
-void
+static void
 gyrus_admin_pre_login (GyrusAdmin *admin)
 {
 	GyrusAdminLoginError error;
@@ -983,7 +1011,7 @@ gyrus_admin_pre_login (GyrusAdmin *admin)
 
 
 /*** Public Methods ****/
-gboolean
+static gboolean
 gyrus_admin_select_foreach_func (GtkTreeModel *model, GtkTreePath *path,
 				 GtkTreeIter *iter, gpointer data)
 {
@@ -1050,13 +1078,6 @@ gyrus_admin_get_selected_mailbox (GyrusAdmin *admin)
 	return current_mailbox;
 }
 
-void
-gyrus_admin_set_parent_app (GyrusAdmin *admin,
-			    gpointer app)
-{
-	admin->priv->parent_app = app;
-}
-
 gboolean
 gyrus_admin_is_connected (GyrusAdmin *admin)
 {
@@ -1129,15 +1150,17 @@ gyrus_admin_has_current_acl_access (GyrusAdmin *admin)
 
 	return !is_visible;
 }
-void
+
+static void
 gyrus_admin_load_session_info (GyrusAdmin *admin, GyrusSession *session)
 {
+	gchar *port;
+
 	g_return_if_fail (GYRUS_IS_ADMIN (admin));
 
 	if (session == NULL)
 		return;
 	
-	gchar *port;
 	port = g_strdup_printf ("%d", session->port);
 	
 	if (!admin->priv->session) {
@@ -1173,6 +1196,14 @@ gyrus_admin_refresh_users_list (GyrusAdmin *admin)
 	gyrus_admin_get_users_list (admin);
 }
 
+GtkTreeView *
+gyrus_admin_get_users_treeview (GyrusAdmin *admin)
+{
+	g_return_val_if_fail (GYRUS_IS_ADMIN (admin), NULL);
+
+	return g_object_ref (admin->priv->treeview_users);
+}
+
 GtkWidget *
 gyrus_admin_new (GyrusSession *session)
 {
@@ -1189,8 +1220,11 @@ void
 gyrus_admin_on_button_connect_clicked (GtkButton *button,
 				       gpointer user_data)
 {
+	GyrusAdmin *admin;
+
 	g_return_if_fail (GYRUS_ADMIN (user_data));
-	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
+
+	admin = GYRUS_ADMIN (user_data);
 
 	if (gyrus_admin_is_connected (admin)) {
 		gyrus_admin_pre_logout (admin);
@@ -1216,7 +1250,7 @@ gyrus_admin_on_acl_selection_changed (GtkTreeSelection *selection,
 	GtkTreeModel *model;
 	GtkTreeIter  iter;
 
-	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->acl_entry_selection_changed,
+	g_signal_emit (admin, admin_signals [ACL_SELECTION_CHANGED],
 		       0,
 		       gtk_tree_selection_get_selected (selection, &model, &iter),
 		       NULL);
@@ -1229,17 +1263,17 @@ gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
 
 	GtkTreeIter iter;
 	GtkTreeModel *model;
+	gchar *mailbox_path;
+	gchar **tokens;
 	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
 
 	gboolean is_selected = gtk_tree_selection_get_selected (selection, &model, &iter);
 	if (is_selected)
 	{
-		gchar *mailbox_path;
 		gtk_tree_model_get (model, &iter,
 				    COL_MAILBOX_NAME, &mailbox_path,
 				    -1);
 
-		gchar **tokens;
 		tokens = g_strsplit (mailbox_path, gyrus_admin_get_separator_char (admin), 3);
 		gyrus_admin_mailbox_show_info (admin, tokens[1],
 					       mailbox_path);
@@ -1253,7 +1287,7 @@ gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
 		gyrus_admin_mailbox_set_sensitive (admin, FALSE);
 	}
 
-	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->mailbox_selection_changed,
+	g_signal_emit (admin, admin_signals [MAILBOX_SELECTION_CHANGED],
 		       0,
 		       is_selected,
 		       NULL);	
@@ -1270,22 +1304,22 @@ gyrus_admin_on_renderer_toggled (GtkCellRendererToggle *renderer,
 				 gchar *path,
 				 gpointer user_data)
 {
-	g_return_if_fail (GTK_IS_TREE_VIEW_COLUMN (user_data));
-	GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN (user_data);
-	
 	GyrusAdmin *admin;
 	GyrusColumnAcl col;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gboolean has_permission;
-
+	GtkTreeViewColumn *column;
 	gchar *permissions = "lrswipcda";
-	
 	gchar *user;
 	gchar *perm;
 	gchar *mailbox;
 	gchar *error;
 
+	g_return_if_fail (GTK_IS_TREE_VIEW_COLUMN (user_data));
+
+	column = GTK_TREE_VIEW_COLUMN (user_data);
+
 	admin = g_object_get_data (G_OBJECT (column),
 				   "parent-admin");
 	col = GPOINTER_TO_INT (
@@ -1326,7 +1360,7 @@ gyrus_admin_on_renderer_toggled (GtkCellRendererToggle *renderer,
 	g_free (mailbox);
 }
 
-gboolean
+static gboolean
 gyrus_admin_acl_eliminate_model_entry (GtkTreeModel *model,
 				       GtkTreePath *path,
 				       GtkTreeIter *iter,
@@ -1347,18 +1381,20 @@ gyrus_admin_acl_eliminate_model_entry (GtkTreeModel *model,
 	return FALSE;
 }
 
-gboolean
+static gboolean
 gyrus_admin_ask_user_if_overwrite (GyrusAdmin *admin,
 				   gchar *entry_name)
 {
 	GtkWidget *dialog;
+	int result;
+
 	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_YES_NO,
 					 _("An entry called '%s' already exists. Overwrite it?"),
 					 entry_name);
 	
-	int result = gtk_dialog_run (GTK_DIALOG (dialog));
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 	
 	return (result == GTK_RESPONSE_YES);
@@ -1376,6 +1412,9 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 	GtkTreeModel *model;
 	gchar *oldname;
 	gchar *error;
+	gchar *mailbox;
+	GList *acl, *l_iter;
+	gchar *rights;
 	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
 	
 	model = gtk_tree_view_get_model (admin->priv->treeview_acl);
@@ -1393,12 +1432,12 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 		return;
 	}
 
-	gchar *mailbox = g_strdup (gtk_label_get_text
+	mailbox = g_strdup (gtk_label_get_text
 				   (GTK_LABEL (admin->priv->label_mailbox_name)));
-	GList *acl = gyrus_admin_acl_get (admin, mailbox, NULL);
+	acl = gyrus_admin_acl_get (admin, mailbox, NULL);
 
 	/* check it the new name already exists. */
-	GList *l_iter = acl;
+	l_iter = acl;
 	while (l_iter != NULL && !duplicated) {
 		entry = GYRUS_IMAP_ACL_ENTRY (l_iter->data);
 		if (strcmp (entry->identifier, newname) == 0)
@@ -1407,7 +1446,7 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 	}
 
 	/* Obtain the rights of the entry to be renamed */
-	gchar *rights = NULL;
+	rights = NULL;
 	l_iter = acl;
 	while (l_iter != NULL && rights == NULL) {
 		entry = GYRUS_IMAP_ACL_ENTRY (l_iter->data);
