@@ -89,7 +89,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 /*** Private API ***/
 
-void
+static void
 gyrus_connection_receive (GyrusConnection *conn)
 {
 	g_return_if_fail (GYRUS_IS_CONNECTION (conn));
@@ -101,7 +101,7 @@ gyrus_connection_receive (GyrusConnection *conn)
  * buffer: a buffer to copy the first "size" bytes.
  */
 #ifdef HAVE_GNUTLS
-gssize
+static gssize
 gyrus_connection_tls_read (GyrusConnection *conn,
                            gchar *buffer, gsize size)
 {
@@ -206,11 +206,14 @@ gyrus_connection_tls_write (GyrusConnection *conn,
 static void
 gyrus_connection_prepare_ubuffer (GyrusConnection *conn)
 {
+	gchar *buf;
+	GString *line;
+  
 	g_return_if_fail (GYRUS_IS_CONNECTION (conn));
 	g_return_if_fail (conn->priv->buffer != NULL);
 
-	gchar *buf = conn->priv->buffer->str;
-	GString *line = g_string_new ("");
+	buf = conn->priv->buffer->str;
+	line = g_string_new ("");
 	
 	g_string_set_size (conn->priv->ubuffer, 0);
 	g_print ("pure buffer:\n%s\n", buf);
@@ -747,6 +750,8 @@ gyrus_connection_disconnect (GyrusConnection *conn)
 void
 gyrus_connection_send (GyrusConnection *conn, const gchar *buffer)
 {
+	GString *cmd;
+  
 	g_return_if_fail (GYRUS_IS_CONNECTION (conn));
 	g_return_if_fail (buffer != NULL);
 	g_return_if_fail (gyrus_connection_get_connected (conn));
@@ -755,7 +760,7 @@ gyrus_connection_send (GyrusConnection *conn, const gchar *buffer)
 	g_string_set_size (conn->priv->buffer, 0);
 	
 	/* Prepare the request string */
-	GString *cmd = conn->priv->command = g_string_new ("");
+	cmd = conn->priv->command = g_string_new ("");
 	g_string_printf (cmd, "%s %s\n", COMMAND_ID, buffer);
 	
 	g_print ("Sending command <%s> %d bytes\n", cmd->str, cmd->len);
