@@ -112,7 +112,7 @@ gyrus_session_list_free (GSList *sessions)
 	
 /*** module callbacks ***/
 
-void
+static void
 gyrus_session_checkbutton_secure_toggled (GtkWidget *widget,
                                           gpointer data)
 {
@@ -123,14 +123,14 @@ gyrus_session_checkbutton_secure_toggled (GtkWidget *widget,
 				993 : 143);
 }
 
-void
+static void
 gyrus_session_edit_on_button_cancel_clicked (GtkWidget *widget,
 					     gpointer user_data)
 {
 	gtk_widget_destroy (window_edit);
 }
 
-void
+static void
 gyrus_session_edit_on_button_ok_clicked (GtkWidget *widget,
 					 gpointer user_data)
 {
@@ -155,7 +155,7 @@ gyrus_session_edit_on_button_ok_clicked (GtkWidget *widget,
 	gyrus_session_free (session);
 }
 
-void
+static void
 gyrus_session_on_button_properties_clicked (GtkWidget *widget,
 					    gpointer user_data)
 {
@@ -170,7 +170,7 @@ gyrus_session_on_button_properties_clicked (GtkWidget *widget,
 	gyrus_session_free (session);
 }
 
-void
+static void
 gyrus_session_on_button_new_clicked (GtkWidget *widget,
 				     gpointer user_data)
 {
@@ -181,7 +181,7 @@ gyrus_session_on_button_new_clicked (GtkWidget *widget,
 			  gyrus_session_append_session);
 }
 
-void
+static void
 gyrus_session_on_button_open_clicked (GtkWidget *widget,
 				      gpointer user_data)
 {
@@ -190,11 +190,12 @@ gyrus_session_on_button_open_clicked (GtkWidget *widget,
 	gyrus_session_free (session);
 }
 
-void
+static void
 gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 						gpointer user_data)
 {
-	GyrusSession *session = gyrus_session_get_selected_session (TRUE);
+	gchar *host, *port, *user, *path, *sep_char, *usetls;
+	GyrusSession *session = gyrus_session_get_selected_session (TRUE);	
 
 	gchar *key  = g_strconcat (PATH_KEY, "StoredSessions", NULL);
 	GSList *sessions = gconf_client_get_list (conf_client, key,
@@ -212,8 +213,6 @@ gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 			       NULL);
 	gyrus_session_list_free (sessions);
 	
-	gchar *host, *port, *user, *path, *sep_char, *usetls;
-	
 	host = g_strconcat (PATH_SESSIONS, session->name, "/", "Host", NULL);
 	port = g_strconcat (PATH_SESSIONS, session->name, "/", "Port", NULL);
 	user = g_strconcat (PATH_SESSIONS, session->name, "/", "User", NULL);
@@ -240,13 +239,13 @@ gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 	gyrus_session_free (session);
 }
 
-void
+static void
 gyrus_session_on_button_cancel_clicked (GtkWidget *widget, gpointer user_data)
 {
 	gtk_widget_destroy (window);
 }
 
-void
+static void
 gyrus_session_on_row_activated (GtkTreeView       *tree_view,
 				GtkTreePath       *path,
 				GtkTreeViewColumn *column,
@@ -257,7 +256,7 @@ gyrus_session_on_row_activated (GtkTreeView       *tree_view,
 	gyrus_session_free (session);	
 }
 
-void
+static void
 gyrus_session_list_set_sensitive (gboolean sensitive)
 {
 	gtk_widget_set_sensitive (button_open, sensitive);
@@ -265,7 +264,7 @@ gyrus_session_list_set_sensitive (gboolean sensitive)
 	gtk_widget_set_sensitive (button_properties, sensitive);
 }
 
-void
+static void
 gyrus_session_on_entry_changed (GtkEditable *editable,
 				gpointer user_data)
 {
@@ -344,11 +343,12 @@ gyrus_session_is_valid (GyrusSession *session, gchar **why_invalid)
 static void
 gyrus_session_append_session (GyrusSession *new)
 {
-	g_return_if_fail (new != NULL);
-
 	gchar *host, *port, *user, *sep_char, *usetls;
-
 	gchar *name;
+	gchar *key;
+	GSList *sessions, *element;
+	
+	g_return_if_fail (new != NULL);
 
 	if (new->name == NULL)
 	{
@@ -358,11 +358,11 @@ gyrus_session_append_session (GyrusSession *new)
 		return;
 	}
 	
-	gchar *key = g_strconcat (PATH_KEY, "StoredSessions", NULL);
-	GSList *sessions = gconf_client_get_list (conf_client, key,
+	key = g_strconcat (PATH_KEY, "StoredSessions", NULL);
+	sessions = gconf_client_get_list (conf_client, key,
 						  GCONF_VALUE_STRING, NULL);
 
-	GSList * element = g_slist_find_custom (sessions, new->name,
+	element = g_slist_find_custom (sessions, new->name,
 						(GCompareFunc) g_ascii_strcasecmp);
 	if (element) {
 		gchar * msg = g_strdup_printf (_("Session named \"%s\" already exists."),
@@ -407,10 +407,10 @@ gyrus_session_append_session (GyrusSession *new)
 static void
 gyrus_session_set_defaults_from_session (GyrusSession *session)
 {
-	g_return_if_fail (session);
-
 	gint value = 0;
 
+	g_return_if_fail (session);
+
 	gtk_entry_set_text (GTK_ENTRY (entry_host), session->host);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton_port),
 				   (gdouble) session->port);
@@ -489,7 +489,7 @@ gyrus_session_add_session_to_treeview (GyrusSession *session)
 			    -1);
 }
 
-gboolean
+static gboolean
 gyrus_session_on_selection_changed (GtkTreeSelection *selection,
 				    GtkTreeModel *model,
 				    GtkTreePath *path,
@@ -500,7 +500,7 @@ gyrus_session_on_selection_changed (GtkTreeSelection *selection,
 	return TRUE;
 }
 
-gboolean
+static gboolean
 gyrus_session_treeview_on_key_press_event (GtkWidget *widget,
 					   GdkEventKey *event,
 					   gpointer user_data)
@@ -522,7 +522,7 @@ gyrus_session_treeview_on_key_press_event (GtkWidget *widget,
 	return FALSE;
 }
 
-gboolean
+static gboolean
 gyrus_session_on_key_press_event (GtkWidget *widget,
 				  GdkEventKey *event,
 				  gpointer user_data)
@@ -583,7 +583,7 @@ gyrus_session_create_model_sessions (void)
 }
 
 /* If remove is TRUE, the selected item is removed from the array */
-GyrusSession *
+static GyrusSession *
 gyrus_session_get_selected_session (gboolean remove)
 {
 	GtkTreeIter iter;
@@ -660,16 +660,16 @@ gyrus_session_get_with_name (const gchar *name)
 void
 gyrus_session_load_gconf_settings (void)
 {
-	GSList *aux;
 	gchar *key;
 	GyrusSession *session = NULL;
-	
+	GSList *sessions, *aux;
+
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview_sessions),
 				 model_sessions);
 
 	key = g_strconcat (PATH_KEY, "StoredSessions", NULL);
-	GSList *sessions = gconf_client_get_list (conf_client, key,
-						  GCONF_VALUE_STRING, NULL);
+	sessions = gconf_client_get_list (conf_client, key,
+					  GCONF_VALUE_STRING, NULL);
 	g_free (key);
 	
 	if (sessions != NULL)
@@ -690,9 +690,11 @@ gyrus_session_load_gconf_settings (void)
 static void
 gyrus_session_open (GyrusSession *session, gpointer user_data)
 {
+	GyrusMainApp *app;
+
 	g_return_if_fail (GYRUS_IS_MAIN_APP (user_data));
 
-	GyrusMainApp *app = GYRUS_MAIN_APP (user_data);
+	app = GYRUS_MAIN_APP (user_data);
 
 	if (!session->host || !strlen (session->host)) {
 		gyrus_common_show_message(GTK_WINDOW (window),
@@ -845,7 +847,7 @@ gyrus_session_show_sessions (GtkWidget *widget G_GNUC_UNUSED,
 	g_object_unref (G_OBJECT (conf_client));
 }
 
-gboolean 
+static gboolean 
 gyrus_session_seek_session (GtkTreeModel *model,
 			    GtkTreePath *path,
 			    GtkTreeIter *iter,
